<?php

namespace Bixo\CrmRequests\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\CrmRequests\Http\Requests\FaqRequest;
use Bixo\CrmRequests\Interfaces\FaqRepositoryInterface;
use Bixo\CrmRequests\Models\Faq;
use Bixo\CrmRequests\Forms\Faq as Form;

/**
 * APIController  class for faq.
 */
class FaqAPIController extends BaseController
{

    /**
     * Initialize faq resource controller.
     *
     * @param type FaqRepositoryInterface $faq
     *
     * @return null
     */
    public function __construct(FaqRepositoryInterface $faq)
    {
        parent::__construct();
        $this->repository = $faq;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\CrmRequests\Repositories\Criteria\FaqResourceCriteria::class);
    }

    /**
     * Display a list of faq.
     *
     * @return Response
     */
    public function index(FaqRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\CrmRequests\Repositories\Presenter\FaqPresenter::class)
            ->paginate();
    }

    /**
     * Display faq.
     *
     * @param Request $request
     * @param Model   $faq
     *
     * @return Response
     */
    public function show(FaqRequest $request, Faq $faq)
    {
        return $faq->setPresenter(\Bixo\CrmRequests\Repositories\Presenter\FaqListPresenter::class);
        ;
    }

    /**
     * Create new faq.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(FaqRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('crm_requests::faq.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('crm_requests/faq/' . $faq->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('crm_requests/faq');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the faq.
     *
     * @param Request $request
     * @param Model   $faq
     *
     * @return Response
     */
    public function update(FaqRequest $request, Faq $faq)
    {
        try {
            $data = $request->all();

            $faq->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('crm_requests::faq.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('crm_requests/faq/' . $faq->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('crm_requests/faq/' . $faq->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the faq.
     *
     * @param Model   $faq
     *
     * @return Response
     */
    public function destroy(FaqRequest $request, Faq $faq)
    {
        try {
            $faq->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('crm_requests::faq.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('crm_requests/faq/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('crm_requests/faq/' . $faq->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
